package App::Spanel::TailWeblog;

our $DATE = '2019-01-30'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Tail -f spanel HTTP and/or HTTPS access log

__END__

=pod

=encoding UTF-8

=head1 NAME

App::Spanel::TailWeblog - Tail -f spanel HTTP and/or HTTPS access log

=head1 VERSION

This document describes version 0.002 of App::Spanel::TailWeblog (from Perl distribution App-Spanel-TailWeblog), released on 2019-01-30.

=head1 SYNOPSIS

See the included L<spanel-tail-weblog> script.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-Spanel-TailWeblog>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-Spanel-TailWeblog>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Spanel-TailWeblog>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
